package data.missions.dara_evangelism;

import com.fs.starfarer.api.fleet.FleetGoal;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.impl.campaign.ids.StarTypes;
import com.fs.starfarer.api.mission.FleetSide;
import com.fs.starfarer.api.mission.MissionDefinitionAPI;
import com.fs.starfarer.api.mission.MissionDefinitionPlugin;

public class MissionDefinition implements MissionDefinitionPlugin {

	public void defineMission(MissionDefinitionAPI api) {

		// Set up the fleets so we can add ships and fighter wings to them.
		// In this scenario, the fleets are attacking each other, but
		// in other scenarios, a fleet may be defending or trying to escape
		api.initFleet(FleetSide.PLAYER, "", FleetGoal.ATTACK, false);
		api.initFleet(FleetSide.ENEMY, "ISS", FleetGoal.ATTACK, true);

//		api.getDefaultCommander(FleetSide.PLAYER).getStats().setSkillLevel(Skills.COORDINATED_MANEUVERS, 3);
//		api.getDefaultCommander(FleetSide.PLAYER).getStats().setSkillLevel(Skills.ELECTRONIC_WARFARE, 3);
		
		// Set a small blurb for each fleet that shows up on the mission detail and
		// mission results screens to identify each side.
		api.setFleetTagline(FleetSide.PLAYER, "Righteous inquisitors, deliverers of judgement");
		api.setFleetTagline(FleetSide.ENEMY, "Cursed heretics who bring Ludd's wrath upon themselves");
		
		// These show up as items in the bulleted list under 
		// "Tactical Objectives" on the mission detail screen
		api.addBriefingItem("Deliver Ludd's holy judgement to the heretics");
		api.addBriefingItem("Use your fighters to outmass individual targets");
		//api.addBriefingItem("");
		
		// Set up the player's fleet.  Variant names come from the
		// files in data/variants and data/variants/fighters
		api.addToFleet(FleetSide.PLAYER, "dara_mora_Evangelist", FleetMemberType.SHIP, true);
		//api.addToFleet(FleetSide.PLAYER, "cerberus_luddic_path_Attack", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.PLAYER, "dara_junker_OD", FleetMemberType.SHIP, false);
		
		// Set up the enemy fleet.
		api.addToFleet(FleetSide.ENEMY, "dara_triton_Support", FleetMemberType.SHIP, true);
		api.addToFleet(FleetSide.ENEMY, "lasher_CS", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "dara_sparrow_Strike", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "wayfarer_Standard", FleetMemberType.SHIP, false);
		
		//api.defeatOnShipLoss("Stranger II");
		
		// Set up the map.
		float width = 15000f;
		float height = 10000f;
		api.initMap((float)-width/2f, (float)width/2f, (float)-height/2f, (float)height/2f);
		
		float minX = -width/2;
		float minY = -height/2;
		
		// Add an asteroid field
		//api.addAsteroidField(minX, minY + height / 2, 0, 8000f,
		//					 20f, 70f, 100);
		
		api.addPlanet(0, 0, 50f, StarTypes.WHITE_DWARF, 250f, true);
		
	}

}
