package data.missions.dara_trainwreck;

import com.fs.starfarer.api.fleet.FleetGoal;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.impl.campaign.ids.StarTypes;
import com.fs.starfarer.api.mission.FleetSide;
import com.fs.starfarer.api.mission.MissionDefinitionAPI;
import com.fs.starfarer.api.mission.MissionDefinitionPlugin;

public class MissionDefinition implements MissionDefinitionPlugin {

	public void defineMission(MissionDefinitionAPI api) {

		// Set up the fleets so we can add ships and fighter wings to them.
		// In this scenario, the fleets are attacking each other, but
		// in other scenarios, a fleet may be defending or trying to escape
		api.initFleet(FleetSide.PLAYER, "ISS", FleetGoal.ESCAPE, false);
		api.initFleet(FleetSide.ENEMY, "", FleetGoal.ATTACK, true);

//		api.getDefaultCommander(FleetSide.PLAYER).getStats().setSkillLevel(Skills.COORDINATED_MANEUVERS, 3);
//		api.getDefaultCommander(FleetSide.PLAYER).getStats().setSkillLevel(Skills.ELECTRONIC_WARFARE, 3);
		
		// Set a small blurb for each fleet that shows up on the mission detail and
		// mission results screens to identify each side.
		api.setFleetTagline(FleetSide.PLAYER, "Last of Galloway's prospecting expedition");
		api.setFleetTagline(FleetSide.ENEMY, "Pirate ambush");
		
		// These show up as items in the bulleted list under 
		// "Tactical Objectives" on the mission detail screen
		api.addBriefingItem("Defend the Untold while she provides fighter and fire support");
		api.addBriefingItem("Use the Poetry's system to dash in and burst down targets, but be careful of overextending");
		api.addBriefingItem("Take advantage of the Poetry's temporary immunity to nebula and EMP damage");
		api.addBriefingItem("Do not let either ship be destroyed");
		
		// Set up the player's fleet.  Variant names come from the
		// files in data/variants and data/variants/fighters
		api.addToFleet(FleetSide.PLAYER, "dara_lysander_CQ", FleetMemberType.SHIP, "ISS Poetry In Motion", true);
		api.addToFleet(FleetSide.PLAYER, "dara_starlifter_Armed", FleetMemberType.SHIP, "ISS Encounters Untold", false);
		
		// Set up the enemy fleet.
		api.addToFleet(FleetSide.ENEMY, "dara_eagle_d_Attack", FleetMemberType.SHIP, true);
		//api.addToFleet(FleetSide.ENEMY, "dara_bull_Raider", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "dara_mousetrap_Assault", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "dara_retribution_Outdated", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "falcon_d_CS", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "dara_chakram_mkii_Assault", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "hammerhead_d_CS", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "lasher_d_CS", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "cerberus_d_pirates_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "cerberus_d_pirates_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "dara_junker_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "dara_mirage_FS", FleetMemberType.SHIP, false);
		
		api.defeatOnShipLoss("ISS Poetry In Motion");
		api.defeatOnShipLoss("ISS Encounters Untold");
		
		// Set up the map.
		float width = 15000f;
		float height = 16000f;
		api.initMap((float)-width/2f, (float)width/2f, (float)-height/2f, (float)height/2f);
		
		float minX = -width/2;
		float minY = -height/2;

		for (int i = 0; i < 25; i++) {
			float x = (float) Math.random() * width - width/2;
			float y = (float) Math.random() * height - height/2;
			float radius = 1000f + (float) Math.random() * 1000f; 
			api.addNebula(x, y, radius);
		}
		
		// Add an asteroid field
		//api.addAsteroidField(minX, minY + height / 2, 0, 8000f,
		//					 20f, 70f, 100);
		
		//api.addPlanet(0, 0, 50f, StarTypes.RED_GIANT, 250f, true);
		
	}

}
